function createfigure(simTV1, einsnT1, einsnT2, zweinT1, zweinT2, dreinT1, dreinT2, viernT1, viernT2)
%CREATEFIGURE(SIMTV1,EINSNT1,EINSNT2,ZWEINT1,ZWEINT2,DREINT1,DREINT2,VIERNT1,VIERNT2)
%  SIMTV1:  vector of y data
%  EINSNT1:  vector of x data
%  EINSNT2:  vector of y data
%  ZWEINT1:  vector of x data
%  ZWEINT2:  vector of y data
%  DREINT1:  vector of x data
%  DREINT2:  vector of y data
%  VIERNT1:  vector of x data
%  VIERNT2:  vector of y data

%  Auto-generated by MATLAB on 28-Feb-2009 19:00:50

% Create figure
figure1 = figure('XVisual',...
    '0x54 (TrueColor, depth 32, RGB mask 0xff0000 0xff00 0x00ff)',...
    'PaperSize',[20.98 29.68]);

% Create axes
axes1 = axes('Parent',figure1);
% Uncomment the following line to preserve the Y-limits of the axes
% ylim([0 4.5]);
box('on');
hold('all');

% Create plot
plot(simTV1,'Parent',axes1,'LineStyle',':');

% Create plot
plot(einsnT1,einsnT2,'Parent',axes1,'Marker','diamond','LineStyle','none');

% Create plot
plot(zweinT1,zweinT2,'Parent',axes1,'MarkerSize',8,'Marker','pentagram',...
    'LineStyle','none');

% Create plot
plot(dreinT1,dreinT2,'Parent',axes1,'Marker','*','LineStyle','none');

% Create plot
plot(viernT1,viernT2,'Parent',axes1,'Marker','.','LineStyle','none');

% Create legend
legend1 = legend(axes1,'show');
set(legend1,'Visible','off','Position',[0.7853 0.2959 0.1137 0.5193]);

